import * as React from 'react';
import { EditorProps } from '@monaco-editor/react';
import type * as monaco from 'monaco-editor';
import { EnrichedLanguageService } from './EnrichedLanguageService';
import { DecorationsSource, DefinitionSource, DiagnosticsSource, EditorAction, HoverSource } from './utils';
import { GraphQLError, GraphQLSchema } from 'graphql';
export declare type EditorApi = {
    jumpToType(typeName: string): void;
    jumpToField(typeName: string, fieldName: string): void;
};
export declare type SchemaEditorProps = {
    schema?: string;
    hoverProviders?: HoverSource[];
    definitionProviders?: DefinitionSource[];
    diagnosticsProviders?: DiagnosticsSource[];
    decorationsProviders?: DecorationsSource[];
    actions?: EditorAction[];
    onBlur?: (value: string) => void;
    onLanguageServiceReady?: (languageService: EnrichedLanguageService) => void;
    onSchemaChange?: (schema: GraphQLSchema, sdl: string) => void;
    onSchemaError?: (errors: [GraphQLError], sdl: string, languageService: EnrichedLanguageService) => void;
    sharedLanguageService?: EnrichedLanguageService;
    keyboardShortcuts?: (editorInstance: monaco.editor.IStandaloneCodeEditor, monacoInstance: typeof monaco) => monaco.editor.IActionDescriptor[];
} & Omit<EditorProps, 'language'>;
export declare const SchemaEditor: React.ForwardRefExoticComponent<{
    schema?: string | undefined;
    hoverProviders?: HoverSource[] | undefined;
    definitionProviders?: DefinitionSource[] | undefined;
    diagnosticsProviders?: DiagnosticsSource[] | undefined;
    decorationsProviders?: DecorationsSource[] | undefined;
    actions?: EditorAction[] | undefined;
    onBlur?: ((value: string) => void) | undefined;
    onLanguageServiceReady?: ((languageService: EnrichedLanguageService) => void) | undefined;
    onSchemaChange?: ((schema: GraphQLSchema, sdl: string) => void) | undefined;
    onSchemaError?: ((errors: [GraphQLError], sdl: string, languageService: EnrichedLanguageService) => void) | undefined;
    sharedLanguageService?: EnrichedLanguageService | undefined;
    keyboardShortcuts?: ((editorInstance: monaco.editor.IStandaloneCodeEditor, monacoInstance: typeof monaco) => monaco.editor.IActionDescriptor[]) | undefined;
} & Omit<EditorProps, "language"> & React.RefAttributes<EditorApi>>;
